I fixed your fiddle to get the normal unrolled version 4x faster. Please see: https://jsfiddle.net/Lmzqpr03/
Largely, the use modern javascript and proper benchmarking made the results more consistent with the benchmark posted.
This included
1) avoiding the use of "var" (using let for scoped iterator variables and const for unchanging references)
2) using proper warmup (10% of runs)
3) isolating the benchmarked code into a function that can be invoked within a loop
4) reseting the values of the arrays being added between benchmarks (to prevent any NaNs/infinities from cropping up)